\$ momo\_
==========

Momo是一款基于Python实现的轻量级的CLI tool，它基于browser webdrive实现了在 www.xuexi.com 网站上自动打开图文或者视频连接，并自动实现浏览器页面自动
向下翻页功能，用以模拟人的真实阅读行为。如果扫码登录还能自动累计积分哦！


Installing
----------


Install using `pip`_:

.. code-block:: text

    $ pip install momo_ma

MOMO supports Python 3.5 and newer.

.. _pip: https://pip.pypa.io/en/stable/quickstart/


Usage Example
----------------

How to use it? Here is an example of a momo  usage:

.. image:: usage-example.png
    :align: center
    :scale: 50%






Links
-----

*   Documentation: https://github.com/liuweicai/momo
*   Code: https://github.com/liuweicai/momo
*   PyPI: https://pypi.org/project/momo-ma
